## Code Changes

- Reorganized the project as Python package
- Switched from INI to TOML format for config files
- Feeds can now only be in Atom format
- Removed environment variable for config file path
- Added CLI parameter (`-c`) for config file path
- Invocation via `hoyolab-rss-feeds` command

## Project Changes

- Changed license from Unlicense to MIT
- Publishing project to PyPI
